@@ -46,16 +46,16 @@
      K_CLUSTER = 264,
      K_CLUSTERNAME = 265,
      K_COMMENT = 266,
-     K_CONFIRMED = 267,
-     K_CONFIG = 268,
+     K_CONFIG = 267,
+     K_CONFIRMED = 268,
      K_CONNINFO = 269,
      K_CONNRETRY = 270,
      K_COPY = 271,
      K_CREATE = 272,
-     K_DROP = 273,
-     K_ECHO = 274,
-     K_DATE = 275,
-     K_DFORMAT = 276,
+     K_DATE = 273,
+     K_DFORMAT = 274,
+     K_DROP = 275,
+     K_ECHO = 276,
      K_ERROR = 277,
      K_EVENT = 278,
      K_EXECUTE = 279,
@@ -82,43 +82,45 @@
      K_NODE = 300,
      K_OFF = 301,
      K_OLD = 302,
-     K_OMIT = 303,
-     K_ON = 304,
-     K_ONLY = 305,
-     K_ORIGIN = 306,
-     K_PATH = 307,
-     K_PREPARE = 308,
-     K_PROVIDER = 309,
-     K_QUALIFIED = 310,
-     K_RECEIVER = 311,
-     K_REPAIR = 312,
-     K_RESTART = 313,
-     K_SCRIPT = 314,
-     K_SECONDS = 315,
-     K_SEQUENCE = 316,
-     K_SERVER = 317,
-     K_SET = 318,
-     K_STORE = 319,
-     K_SUBSCRIBE = 320,
-     K_SUCCESS = 321,
-     K_SWITCH = 322,
+     K_ON = 303,
+     K_ONLY = 304,
+     K_ORIGIN = 305,
+     K_PATH = 306,
+     K_PREPARE = 307,
+     K_PROVIDER = 308,
+     K_QUALIFIED = 309,
+     K_RECEIVER = 310,
+     K_RESTART = 311,
+     K_SCRIPT = 312,
+     K_SEQUENCE = 313,
+     K_SERVER = 314,
+     K_SET = 315,
+     K_SLEEP = 316,
+     K_SQL = 317,
+     K_STORE = 318,
+     K_SUBSCRIBE = 319,
+     K_SUCCESS = 320,
+     K_SWITCH = 321,
+     K_SYNC = 322,
      K_TABLE = 323,
-     K_TABLES = 324,
-     K_SEQUENCES = 325,
-     K_TIMEOUT = 326,
-     K_TRUE = 327,
-     K_TRY = 328,
-     K_UNINSTALL = 329,
-     K_UNLOCK = 330,
-     K_UNSUBSCRIBE = 331,
-     K_UPDATE = 332,
-     K_YES = 333,
-     K_WAIT = 334,
-     K_SYNC = 335,
-     K_SLEEP = 336,
-     T_IDENT = 337,
-     T_LITERAL = 338,
-     T_NUMBER = 339
+     K_TIMEOUT = 324,
+     K_TRUE = 325,
+     K_TRY = 326,
+     K_UNINSTALL = 327,
+     K_UNLOCK = 328,
+     K_UNSUBSCRIBE = 329,
+     K_UPDATE = 330,
+     K_WAIT = 331,
+     K_YES = 332,
+     K_OMIT = 333,
+     K_REPAIR = 334,
+     K_RESUBSCRIBE = 335,
+     K_SECONDS = 336,
+     K_SEQUENCES = 337,
+     K_TABLES = 338,
+     T_IDENT = 339,
+     T_LITERAL = 340,
+     T_NUMBER = 341
    };
 #endif
 /* Tokens.  */
@@ -131,16 +133,16 @@
 #define K_CLUSTER 264
 #define K_CLUSTERNAME 265
 #define K_COMMENT 266
-#define K_CONFIRMED 267
-#define K_CONFIG 268
+#define K_CONFIG 267
+#define K_CONFIRMED 268
 #define K_CONNINFO 269
 #define K_CONNRETRY 270
 #define K_COPY 271
 #define K_CREATE 272
-#define K_DROP 273
-#define K_ECHO 274
-#define K_DATE 275
-#define K_DFORMAT 276
+#define K_DATE 273
+#define K_DFORMAT 274
+#define K_DROP 275
+#define K_ECHO 276
 #define K_ERROR 277
 #define K_EVENT 278
 #define K_EXECUTE 279
@@ -167,43 +169,45 @@
 #define K_NODE 300
 #define K_OFF 301
 #define K_OLD 302
-#define K_OMIT 303
-#define K_ON 304
-#define K_ONLY 305
-#define K_ORIGIN 306
-#define K_PATH 307
-#define K_PREPARE 308
-#define K_PROVIDER 309
-#define K_QUALIFIED 310
-#define K_RECEIVER 311
-#define K_REPAIR 312
-#define K_RESTART 313
-#define K_SCRIPT 314
-#define K_SECONDS 315
-#define K_SEQUENCE 316
-#define K_SERVER 317
-#define K_SET 318
-#define K_STORE 319
-#define K_SUBSCRIBE 320
-#define K_SUCCESS 321
-#define K_SWITCH 322
+#define K_ON 303
+#define K_ONLY 304
+#define K_ORIGIN 305
+#define K_PATH 306
+#define K_PREPARE 307
+#define K_PROVIDER 308
+#define K_QUALIFIED 309
+#define K_RECEIVER 310
+#define K_RESTART 311
+#define K_SCRIPT 312
+#define K_SEQUENCE 313
+#define K_SERVER 314
+#define K_SET 315
+#define K_SLEEP 316
+#define K_SQL 317
+#define K_STORE 318
+#define K_SUBSCRIBE 319
+#define K_SUCCESS 320
+#define K_SWITCH 321
+#define K_SYNC 322
 #define K_TABLE 323
-#define K_TABLES 324
-#define K_SEQUENCES 325
-#define K_TIMEOUT 326
-#define K_TRUE 327
-#define K_TRY 328
-#define K_UNINSTALL 329
-#define K_UNLOCK 330
-#define K_UNSUBSCRIBE 331
-#define K_UPDATE 332
-#define K_YES 333
-#define K_WAIT 334
-#define K_SYNC 335
-#define K_SLEEP 336
-#define T_IDENT 337
-#define T_LITERAL 338
-#define T_NUMBER 339
+#define K_TIMEOUT 324
+#define K_TRUE 325
+#define K_TRY 326
+#define K_UNINSTALL 327
+#define K_UNLOCK 328
+#define K_UNSUBSCRIBE 329
+#define K_UPDATE 330
+#define K_WAIT 331
+#define K_YES 332
+#define K_OMIT 333
+#define K_REPAIR 334
+#define K_RESUBSCRIBE 335
+#define K_SECONDS 336
+#define K_SEQUENCES 337
+#define K_TABLES 338
+#define T_IDENT 339
+#define T_LITERAL 340
+#define T_NUMBER 341
 
 
 
@@ -220,11 +224,12 @@ typedef union YYSTYPE
 	option_list	*opt_list;
 	SlonikAdmInfo	*adm_info;
 	SlonikStmt	*statement;
+	failed_node_entry * failed_node_entry;
 
 
 
 /* Line 2068 of yacc.c  */
-#line 228 "y.tab.h"
+#line 233 "y.tab.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
